<template>
  <el-dialog
    width="60%"
    title="IFS库存物料"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <div>
      <span>需求数量：</span
      ><span style="color:Red;">{{
        materialRow == null
          ? ''
          : materialRow.surplusQuantity +
            (detailRow == null ? 0 : detailRow.transferQuantity) -
            totalPlanMoveQuality
      }}</span>
    </div>
    <el-table
      class="ifs-stock-table"
      :data="ifsStockData"
      style="width: 100%;"
      height="450px"
      border
      @current-change="handleCurrentChange"
      stripe
      ref="detailIfsStockTable"
    >
      <el-table-column align="center" width="55">
        <template slot-scope="scope">
          <el-checkbox
            class="detail-ifs-stock-table-single-checkbox"
            v-model="scope.row.commonChecked"
            disabled
          ></el-checkbox>
        </template>
      </el-table-column>
      <el-table-column type="index" width="50" label="序号"> </el-table-column>
      <el-table-column
        prop="partNo"
        label="零件号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partDesc"
        label="零件描述"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="locationDesc"
        label="库位"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="batchNo"
        label="批次号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="wdr"
        label="WDR"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="available"
        label="可用库存数量"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="planMoveQuality"
        label="计划移库数量"
        align="center"
      >
        <template slot-scope="scope">
          <el-input
            v-model="scope.row.planMoveQuality"
            @blur="blurChangeCallback(scope.row)"
          ></el-input>
        </template>
      </el-table-column>
      <el-table-column prop="unit" label="单位" align="center">
      </el-table-column>
      <el-table-column prop="engChgLevel" label="版本" align="center">
      </el-table-column>
    </el-table>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >修 改</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { getIfsStock } from '@/api/warehouse/stock'
import { putPalletTransportsDetail } from '@/api/warehouse/pallettransports'
export default {
  components: {},
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    transportsRow: {
      type: Object,
      default: () => {
        return {}
      }
    },
    materialRow: {
      type: Object,
      default: () => {
        return {}
      }
    },
    detailRow: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      totalPlanMoveQuality: 0,
      ifsStockData: [],
      currStockRow: null
    }
  },
  methods: {
    // 单行选中
    handleCurrentChange(row) {
      if (row != null) {
        this.ifsStockData.forEach((item) => {
          // 排他,每次选择时把其他选项都清除
          if (item.id !== row.id) {
            item.commonChecked = false
          } else {
            item.commonChecked = true
          }
        })
      } else {
        this.ifsStockData.forEach((item) => {
          // 选项都清除
          item.commonChecked = false
        })
      }
      this.currStockRow = row
      this.checkQuality()
    },
    blurChangeCallback(row) {
      this.checkQuality()
    },
    checkQuality() {
      // 勾选合计校验，是否大于需求数量
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.ifsStockData.length; i++) {
        if (
          this.ifsStockData[i].planMoveQuality == null ||
          this.ifsStockData[i].planMoveQuality == ''
        ) {
          flag = false
          flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量不能为空；'
        } else {
          if (!this.checkZero(this.ifsStockData[i].planMoveQuality)) {
            flag = false
            flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量不能为0；'
          } else {
            if (!this.checkPositive(this.ifsStockData[i].planMoveQuality)) {
              flag = false
              flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量需为正数；'
            } else {
              if (!this.checkDecimal(this.ifsStockData[i].planMoveQuality)) {
                flag = false
                flagMsg =
                  flagMsg + '第' + (i + 1) + '行，计划移库数量最多六位小数；'
              } else {
                if (
                  this.ifsStockData[i].planMoveQuality >
                  this.ifsStockData[i].available
                ) {
                  flag = false
                  flagMsg =
                    flagMsg +
                    '第' +
                    (i + 1) +
                    '行，计划移库数量大于可用库存数量；'
                }
              }
            }
          }
        }
      }
      if (flag) {
        this.totalPlanMoveQuality = 0
        if (this.currStockRow != null) {
          this.totalPlanMoveQuality =
            this.totalPlanMoveQuality +
            Number(this.currStockRow.planMoveQuality)

          if (
            Number(this.materialRow.surplusQuantity) +
              Number(this.detailRow.transferQuantity) <
            Number(this.totalPlanMoveQuality)
          ) {
            flag = false
            this.$message.error('计划移库数量大于需求数量；')
          }
        }
      } else {
        this.$message.error(flagMsg)
      }
      return flag
    },
    checkZero(value) {
      if (value == 0) {
        return false
      } else {
        return true
      }
    },
    checkPositive(value) {
      if (!/^[0-9]+.?[0-9]*$/.test(value)) {
        return false
      } else {
        return true
      }
    },
    checkDecimal(value) {
      if (
        !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
          value
        )
      ) {
        return false
      } else {
        return true
      }
    },
    saveSelectRow() {
      this.isSubmit = true
      const flag = this.checkQuality()
      if (flag) {
        const transportsDetail = {
          id: this.detailRow.id,
          batchNo: this.currStockRow.batchNo,
          wdr: this.currStockRow.wdr,
          transferQuantity: this.currStockRow.planMoveQuality,
          fromIfsLocationNo: this.currStockRow.locationNo
        }

        putPalletTransportsDetail(transportsDetail)
          .then((response) => {
            const resData = response.data
            if (resData.code === 0) {
              this.innerVisible = false
              this.$message.success('修改移库明细成功')
              this.$emit('refreshDataList')
            } else {
              this.$message.error('修改移库明细失败')
            }
            this.isSubmit = false
          })
          .catch(() => {
            this.isSubmit = false
          })
      } else {
        this.isSubmit = false
      }
    },
    initData() {
      this.currStockRow = null
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.initData()
        this.ifsStockData = []
        this.$nextTick(() => {
          // 根据零件号查询ifs物料库存
          const queryParam = {
            partNo: this.materialRow.partNo
          }
          getIfsStock(queryParam).then((response) => {
            const resData = response.data
            if (resData.code === 0) {
              const dataList = resData.data
              if (dataList && dataList.length > 0) {
                dataList.forEach((item, index) => {
                  this.ifsStockData.push({
                    id: index + 1,
                    partNo: item.PART_NO,
                    partDesc: item.PART_DESC,
                    locationDesc: item.LOCATION_DESC,
                    locationNo: item.LOCATION_NO,
                    batchNo: item.LOT_BATCH_NO,
                    wdr: item.WAIV_DEV_REJ_NO,
                    available: Number(item.QTY_AVAILABLE),
                    unit: item.UNIT_MEAS_DESC,
                    engChgLevel: item.ENG_CHG_LEVEL,
                    planMoveQuality: Number(item.QTY_AVAILABLE),
                    commonChecked: false
                  })
                })
              }
            }
          })
        })
      }
    }
  }
}
</script>
<style scoped>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
.detail-ifs-stock-table-single-checkbox
  >>> .el-checkbox__input.is-disabled.is-checked
  .el-checkbox__inner {
  background-color: #006eff;
  border-color: #006eff;
}
.detail-ifs-stock-table-single-checkbox
  >>> .el-checkbox__input.is-disabled
  .el-checkbox__inner {
  background-color: #ffffff;
  cursor: pointer;
}
.detail-ifs-stock-table-single-checkbox >>> .el-checkbox__inner::after {
  border: 1px solid #fff !important;
  border-left: 0 !important;
  border-top: 0 !important;
  cursor: pointer !important;
}
</style>
